summaryrefslogtreecommitdiff
path: root/service/reload/config.go
diff options
context:
space:
mode:
Diffstat (limited to 'service/reload/config.go')
-rw-r--r--service/reload/config.go8
1 files changed, 5 insertions, 3 deletions
diff --git a/service/reload/config.go b/service/reload/config.go
index 338c6eba..fb704015 100644
--- a/service/reload/config.go
+++ b/service/reload/config.go
@@ -15,9 +15,11 @@ type Config struct {
}
type ServiceConfig struct {
- // Watch is per-service specific files to watch
- Watch []string
- // Dirs is per-service specific dirs which will be combined with Watch
+ // Recursive is options to use nested files from root folder
+ Recursive bool
+ // Patterns is per-service specific files to watch
+ Patterns []string
+ // Dirs is per-service specific dirs which will be combined with Patterns
Dirs []string
// Ignore is set of files which would not be watched
Ignore []string